is_ignored_path

Function is_ignored_path 

pub fn is_ignored_path(file: &Path, paths: &[PathBuf], base: &Path) -> bool
Returns whether file is contained in paths, or lies underneath a directory contained in paths.

Expanded ignore globs can contain directories, e.g. test/** yields the directories under test, so an ignore check must also match the files below every entry. base is used to resolve file when it is relative.